@@ -5,6 +5,7 @@
 from datetime import datetime
 import sdc_helpers.utils as utils
 import boto3
+from sagemaker.utils import name_from_base
 from sdc_engine_helpers.date_utils import DateUtils
 
 class SolutionStateManager:
@@ -80,9 +81,14 @@ class SolutionStateManager:
                 })
 
         # update fields
-        # in python3, a time suffix is automatically added
+        # generate a unique name with timestamp
+        new_training_job_name = name_from_base(
+            new_solution_name,
+            max_length=63,
+            short=False
+        )
         new_training_job.update({
-            'TrainingJobName': new_solution_name
+            'TrainingJobName': new_training_job_name
         })
 
         self.sagemaker.create_training_job(**new_training_job)
